@@ -153,7 +153,8 @@ class MigrationCommand(BaseCommand):
                             continue  # only migrating objects with errors
                     except MigratedObject.DoesNotExist:
                         continue  # no migration means object was no migrated with error
-                elif obj is not None and self.only_new_objects:
+                elif obj is not None and self.only_new_objects and \
+                     MigratedObject.objects.object_migrations(obj).exists():
                     self.debug('%d. Skip "%s" object' % (i, obj))
                     continue  # no migration for non new objects
                 if obj is None:
